nvector._core.on_great_circle_path — nvector 0.7.5 documentation

# nvector._core.on_great_circle_path

`on_great_circle_path`(path, n_EB_E, radius=6371009.0, atol=1e-08)

  True if position B is on great circle and between endpoints of path A.

  Parameters
    path: tuple of 2 n-vectors

      > 2 n-vectors of positions defining path A, decomposed in E.

      n_EB_E: 3 x m array

        n-vector(s) of position B to measure the cross track distance to.

      radius: real scalar

        radius of sphere. (default 6371009.0)

      atol: real scalars

        The absolute tolerance parameter (See notes).

  Returns
    onbool array of length max(n, m)

      True if position B is on great circle and between endpoints of path A.

  Notes

  The default value of atol is not zero, and is used to determine what small values should be considered close to zero. The default value is appropriate for expected values of order unity. However, atol should be carefully selected for the use case at hand. Typically the value should be set to the accepted error tolerance. For GPS data the error ranges from 0.01 m to 15 m.